searchNodes=[{"ref":"Formulae.html","title":"Formulae","type":"module","doc":"A set of functions to deal with analytical formulae."},{"ref":"Formulae.html#bindings?/2","title":"Formulae.bindings?/2","type":"function","doc":"Returns the binding this formula requires. Examples iex&gt; &quot;a &gt; 5&quot; |&gt; Formulae.bindings? ~w|a|a iex&gt; &quot;:math.sin(a / (3.14 * b)) &gt; c&quot; |&gt; Formulae.bindings? ~w|a b c|a iex&gt; &quot;a + b * 4 - :math.pow(c, 2) / d &gt; 1.0 * e&quot; |&gt; Formulae.bindings? ~w|a b c d e|a"},{"ref":"Formulae.html#check/2","title":"Formulae.check/2","type":"function","doc":"Revalidates the formula with bindings given. Returns true if the formula strictly evaluates to true, false otherwise. Compiles the formula before evaluation if needed."},{"ref":"Formulae.html#compile/1","title":"Formulae.compile/1","type":"function","doc":"Compiles the formula into module. Examples: iex&gt; f = Formulae.compile(&quot;rem(a, 5) - b == 0&quot;) iex&gt; f.formula &quot;rem(a, 5) - b == 0&quot; iex&gt; f.variables [:a, :b] iex&gt; f.module :&quot;Elixir.Formulae.rem(a, 5) - b == 0&quot; iex&gt; f.module.eval(a: 12, b: 2) true iex&gt; f = Formulae.compile(&quot;rem(a, 5) - b == 0&quot;) iex&gt; f.eval.(a: 11, b: 1) true iex&gt; f.eval.(a: 12, b: 1) false"},{"ref":"Formulae.html#compiled?/1","title":"Formulae.compiled?/1","type":"function","doc":"Checks whether the formula was already compiled into module. Examples: iex&gt; Formulae.compiled?(&quot;foo &gt; 42&quot;) false iex&gt; Formulae.compile(&quot;foo &gt; 42&quot;) iex&gt; Formulae.compiled?(&quot;foo &gt; 42&quot;) true"},{"ref":"Formulae.html#curry/3","title":"Formulae.curry/3","type":"function","doc":"Curries the formula by substituting the known bindings into it. Example iex&gt; Formulae.curry(&quot;(temp - foo * 4) &gt; speed / 3.14&quot;, temp: 7, speed: 3.14).formula &quot;7 - foo * 4 &gt; 3.14 / 3.14&quot;"},{"ref":"Formulae.html#eval/2","title":"Formulae.eval/2","type":"function","doc":"Evaluates the formula returning the result back. Examples: iex&gt; Formulae.eval(&quot;rem(a, 5) + rem(b, 4) == 0&quot;, a: 20, b: 20) true iex&gt; Formulae.eval(&quot;rem(a, 5) == 0&quot;, a: 21) false iex&gt; Formulae.eval(&quot;rem(a, 5) + rem(b, 4)&quot;, a: 21, b: 22) 3"},{"ref":"Formulae.html#evaluate/3","title":"Formulae.evaluate/3","type":"function","doc":"Evaluates normalized representation of formula. Examples iex&gt; Formulae.evaluate(Formulae.unit(&quot;3 &gt; 2&quot;)) true iex&gt; Formulae.evaluate(Formulae.unit(&quot;3 &lt; 2&quot;)) false iex&gt; Formulae.evaluate(Formulae.unit(&quot;a &lt; 2&quot;), [a: 1]) true iex&gt; Formulae.evaluate(Formulae.unit(&quot;a &gt; 2&quot;), [a: 1]) false iex&gt; Formulae.evaluate(Formulae.unit(&quot;a &lt; 2&quot;), []) ** (Formulae.RunnerError) Formula failed to run (compile): incomplete binding to evaluate a formula, lacking: [:a]. iex&gt; Formulae.evaluate(Formulae.unit(&quot;a + 2 = 3&quot;), [a: 1]) true iex&gt; Formulae.evaluate(Formulae.unit(&quot;a + 2 = 3&quot;), [a: 2]) false iex&gt; Formulae.evaluate(Formulae.unit(~S|a = &quot;3&quot;|), [a: &quot;3&quot;]) true iex&gt; Formulae.evaluate(Formulae.unit(~S|a = &quot;3&quot;|), [a: 3]) false iex&gt; Formulae.evaluate(Formulae.unit(~S|a = &quot;3&quot;|), [a: &quot;hello&quot;]) false iex&gt; Formulae.evaluate(&quot;a + 2 = 3&quot;, [a: 2]) false iex&gt; Formulae.evaluate(~S|a = &quot;3&quot;|, [a: &quot;3&quot;]) true iex&gt; Formulae.evaluate(Formulae.unit(&quot;a_b_c_490000 &gt; 2&quot;), [a_b_c_490000: 3]) true"},{"ref":"Formulae.html#normalize/1","title":"Formulae.normalize/1","type":"function","doc":"Returns a normalized representation for the formula given."},{"ref":"Formulae.html#unit/2","title":"Formulae.unit/2","type":"function","doc":"Produces the normalized representation of formula. If the rho is an instance of Integer or Float, it’s left intact, otherwise it’s moved to the left side with negation. Examples iex&gt; Formulae.unit(&quot;3 &gt; 2&quot;) {&quot;3 &gt; 2&quot;, {:&gt;, [], [3, 2]}} iex&gt; Formulae.unit(&quot;3 - a &gt; 2&quot;) {&quot;3 - a &gt; 2&quot;, {:&gt;, [], [{:-, [line: 1], [3, {:a, [line: 1], nil}]}, 2]}} iex&gt; Formulae.unit(&quot;3 &gt; A + 2&quot;) {&quot;3 &gt; a + 2&quot;, {:&gt;, [], [{:-, [context: Formulae, import: Kernel], [3, {:+, [line: 1], [{:a, [line: 1], nil}, 2]}]}, 0]}} iex&gt; Formulae.unit(&quot;3 &gt;= a + 2&quot;) {&quot;3 &gt;= a + 2&quot;, {:&gt;=, [], [{:-, [context: Formulae, import: Kernel], [3, {:+, [line: 1], [{:a, [line: 1], nil}, 2]}]}, 0]}} iex&gt; Formulae.unit(&quot;3 a &gt; A + 2&quot;) ** (Formulae.SyntaxError) Formula [3 a &gt; A + 2] syntax is incorrect (parsing): syntax error before: “a”. iex&gt; Formulae.unit(&quot;a + 2 = 3&quot;) {&quot;a + 2 = 3&quot;, {:==, [], [{:+, [line: 1], [{:a, [line: 1], nil}, 2]}, 3]}} iex&gt; Formulae.unit(~S|A = &quot;3&quot;|) {&quot;a = \\&quot;3\\&quot;&quot;, {:==, [], [{:a, [line: 1], nil}, &quot;3&quot;]}}"},{"ref":"Formulae.html#t:t/0","title":"Formulae.t/0","type":"type","doc":""},{"ref":"Formulae.Combinators.html","title":"Formulae.Combinators","type":"module","doc":"Helper to calculate all the combinations of the list given. Examples iex&gt; Formulae.Combinators.combinations(~w|a b c d|a, 2) [[:a, :b], [:a, :c], [:a, :d], [:b, :c], [:b, :d], [:c, :d]] iex&gt; Formulae.Combinators.permutations(~w|a b c d|a, 2) [[:a, :b], [:a, :c], [:a, :d], [:b, :a], [:b, :c], [:b, :d], [:c, :a], [:c, :b], [:c, :d], [:d, :a], [:d, :b], [:d, :c]] iex&gt; Formulae.Combinators.repeated_permutations(~w|a b c d|a, 2) [[:a, :a], [:a, :b], [:a, :c], [:a, :d], [:b, :a], [:b, :b], [:b, :c], [:b, :d], [:c, :a], [:c, :b], [:c, :c], [:c, :d], [:d, :a], [:d, :b], [:d, :c], [:d, :d]]"},{"ref":"Formulae.Combinators.html#combinations/2","title":"Formulae.Combinators.combinations/2","type":"function","doc":"Calculates all combinations of the list, given as the first parameter"},{"ref":"Formulae.Combinators.html#permutations/2","title":"Formulae.Combinators.permutations/2","type":"function","doc":"Calculates all permutations of the list, given as the first parameter"},{"ref":"Formulae.Combinators.html#repeated_permutations/2","title":"Formulae.Combinators.repeated_permutations/2","type":"function","doc":"Calculates all repeated permutations of the list, given as the first parameter"},{"ref":"Formulae.RunnerError.html","title":"Formulae.RunnerError","type":"exception","doc":""},{"ref":"Formulae.SyntaxError.html","title":"Formulae.SyntaxError","type":"exception","doc":""}]